
import os

from flask import request, current_app as app

from pystache.renderer import Renderer


def _get_renderer(append=None):
    append = append or []

    bp = app.blueprints.get(request.blueprint, None)

    if not bp or not bp.template_folder:
        dirs = [os.path.join(app.import_name, app.template_folder, *append)]
    else:
        path = bp.import_name.split('.') + [bp.template_folder]
        dirs = [os.path.join(*path + append)]

    return Renderer(search_dirs=dirs)


def render_view(view):
    """Render a view object

    :param view: The view object to render
    """
    return _get_renderer().render(view)


def render_template(template, context=None):
    """Renders a given template and context.

    :param template: The template name
    :param context: The template context
    """
    parts = template.split('/')
    renderer = _get_renderer(parts[:-1])
    return renderer.render(renderer.load_template(parts[-1:][0]), context or {})



"""
Flask-Stache
------------

Simple mustache templating for Flask applications

Links
`````

* `development version
  <https://github.com/mattupstate/flask-stache/raw/develop#egg=Flask-Stache-dev>`_

"""

from setuptools import setup

setup(
    name='Flask-Stache',
    version='0.1.0',
    url='https://github.com/mattupstate/flask-stache',
    license='MIT',
    author='Matthew Wright',
    author_email='matt@nobien.net',
    description='Simple mustache templating for Flask applications',
    long_description=__doc__,
    py_modules=['flask_stache'],
    zip_safe=False,
    include_package_data=True,
    platforms='any',
    install_requires=[
        'Flask',
        'pystache'
    ],
    test_suite='nose.collector',
    tests_require=['nose'],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development :: Libraries :: Python Modules'
    ]
)
